drain-swamp current
====================

Non-destructive way to query the current version

From package base folder

.. code-block:: shell

   drain-swamp current

Command options
""""""""""""""""

.. csv-table:: :code:`drain-swamp current` options
   :header: cli, default, description
   :widths: auto

   "-p/--path", "cwd", "absolute path to package base folder"
